@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -84,8 +84,7 @@ do {
     }
 } while (false);
 
-$url = Horde_Util::getFormData('url');
-if (!empty($url)) {
+if ($url = Horde::verifySignedUrl(Horde_Util::getFormData('url'))) {
     $url = new Horde_Url($url, true);
 } else {
     $url = Horde::url($prefs->getValue('defaultview') . '.php', true)
