@@ -492,8 +492,12 @@ class Kronolith_Driver
             foreach ($resources as $uid => $resource) {
                 if ($resource['response'] !== Kronolith::RESPONSE_DECLINED &&
                     $resource['response'] !== Kronolith::RESPONSE_NONE) {
-                    $r = $rd->getResource($uid);
-                    $r->removeEvent($event);
+                    try {
+                        $r = $rd->getResource($uid);
+                        $r->removeEvent($event);
+                    } catch (Horde_Exception_NotFound $e) {
+                    } catch (Kronolith_Exception $e) {
+                    }
                 }
             }
         }
